@@ -71,27 +71,27 @@ class FeatureGroupTemplate(AbstractApiClass):
         """
         return self.client.describe_feature_group_template(self.feature_group_template_id)
 
-    def update(self, template_sql: str = None, template_variables: dict = None):
+    def update(self, template_sql: str = None, template_variables: list = None):
         """
         Update a feature group template.
 
         Args:
             template_sql (str): If provided, the new value to use for the template sql.
-            template_variables (dict): If provided, the new value to use for the template variables.
+            template_variables (list): If provided, the new value to use for the template variables.
 
         Returns:
             FeatureGroupTemplate: The updated feature group template.
         """
         return self.client.update_feature_group_template(self.feature_group_template_id, template_sql, template_variables)
 
-    def preview_resolution(self, template_bindings: dict = None, template_sql: str = None, template_variables: dict = None, should_validate: bool = True):
+    def preview_resolution(self, template_bindings: list = None, template_sql: str = None, template_variables: list = None, should_validate: bool = True):
         """
         Resolve template sql using template variables and template bindings.
 
         Args:
-            template_bindings (dict): Values that overide the template variable values specified by the template.
+            template_bindings (list): Values that overide the template variable values specified by the template.
             template_sql (str): If specified, use this as the template sql instead of the feature group template's sql.
-            template_variables (dict): Template variables to use. If a template is provided, this overrides the template's template variables.
+            template_variables (list): Template variables to use. If a template is provided, this overrides the template's template variables.
             should_validate (bool): 
 
         Returns:
